;; Generated package description from ivy-hydra.el  -*- no-byte-compile: t -*-
(define-package "ivy-hydra" "0.13.4.0.20210310.121237" "Additional key bindings for Ivy" '((emacs "24.5") (ivy "0.13.4") (hydra "0.15.0")) :keywords '("convenience") :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :url "https://github.com/abo-abo/swiper")
